package betterquesting.api2.client.gui.panels.content;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.controls.IValueIO;
import betterquesting.api2.client.gui.controls.io.ValueFuncIO;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.IGuiPanel;
import betterquesting.api2.utils.EntityPlayerPreview;
import com.mojang.authlib.GameProfile;
import java.util.List;
import java.util.UUID;
import net.minecraft.client.Minecraft;
import net.minecraft.client.entity.AbstractClientPlayer;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_panels_content.jar:betterquesting/api2/client/gui/panels/content/PanelPlayerPortrait.class */
public class PanelPlayerPortrait implements IGuiPanel {
    private final IGuiRect transform;
    private boolean enabled;
    private final AbstractClientPlayer player;
    private final IValueIO<Float> basePitch;
    private final IValueIO<Float> baseYaw;
    private IValueIO<Float> pitchDriver;
    private IValueIO<Float> yawDriver;
    private float zDepth;

    public PanelPlayerPortrait(IGuiRect rect, UUID playerID, String username) {
        this(rect, new EntityPlayerPreview(Minecraft.func_71410_x().field_71441_e, new GameProfile(playerID, username)));
    }

    public PanelPlayerPortrait(IGuiRect rect, AbstractClientPlayer player) {
        this.enabled = true;
        this.zDepth = 100.0f;
        this.transform = rect;
        this.player = new EntityPlayerPreview(player.field_70170_p, player.func_146103_bH());
        this.player.field_70754_ba = 0.0f;
        this.player.field_70721_aZ = 0.0f;
        this.player.field_70759_as = 0.0f;
        ResourceLocation resource = this.player.func_110306_p();
        if (Minecraft.func_71410_x().func_110434_K().func_110581_b(resource) == null) {
            AbstractClientPlayer.func_110304_a(resource, player.func_146103_bH().getName());
        }
        this.basePitch = new ValueFuncIO(() -> {
            return Float.valueOf(15.0f);
        });
        this.pitchDriver = this.basePitch;
        this.baseYaw = new ValueFuncIO(() -> {
            return Float.valueOf(-30.0f);
        });
        this.yawDriver = this.baseYaw;
    }

    public PanelPlayerPortrait setRotationFixed(float pitch, float yaw) {
        this.pitchDriver = this.basePitch;
        this.yawDriver = this.baseYaw;
        this.basePitch.writeValue(Float.valueOf(pitch));
        this.baseYaw.writeValue(Float.valueOf(yaw));
        return this;
    }

    public PanelPlayerPortrait setRotationDriven(IValueIO<Float> pitch, IValueIO<Float> yaw) {
        this.pitchDriver = pitch == null ? this.basePitch : pitch;
        this.yawDriver = yaw == null ? this.baseYaw : yaw;
        return this;
    }

    public PanelPlayerPortrait setDepth(float z) {
        this.zDepth = z;
        return this;
    }

    public void initPanel() {
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void drawPanel(int mx, int my, float partialTick) {
        IGuiRect bounds = getTransform();
        GL11.glPushMatrix();
        RenderUtils.startScissor(new GuiRectangle(bounds));
        GL11.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        int scale = Math.min(bounds.getWidth(), bounds.getHeight());
        RenderUtils.RenderEntity(bounds.getX() + (bounds.getWidth() / 2), bounds.getY() + (bounds.getHeight() / 2) + ((int) (scale * 1.5f)), this.zDepth, scale, ((Float) this.yawDriver.readValue()).floatValue(), ((Float) this.pitchDriver.readValue()).floatValue(), this.player);
        RenderUtils.endScissor();
        GL11.glPopMatrix();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseScroll(int mx, int my, int scroll) {
        return false;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        return null;
    }
}
